@@ -2,6 +2,7 @@ import { awscdk, javascript } from 'projen';
 const project = new awscdk.AwsCdkConstructLibrary({
   author: 'yicr',
   authorAddress: 'yicr@users.noreply.github.com',
+  authorOrganization: true,
   cdkVersion: '2.80.0',
   typescriptVersion: '4.9.x',
   jsiiVersion: '~5.0.0',
@@ -10,16 +11,18 @@ const project = new awscdk.AwsCdkConstructLibrary({
   description: 'Specific AWS VPC FlowLog Bucket',
   keywords: ['aws', 'cdk', 'aws-cdk', 's3', 'bucket', 'vpc', 'flow'],
   projenrcTs: true,
-  repositoryUrl: 'https://github.com/yicr/aws-secure-flow-log-bucket.git',
+  repositoryUrl: 'https://github.com/gammarer/aws-secure-flow-log-bucket.git',
+  majorVersion: 1,
   npmAccess: javascript.NpmAccess.PUBLIC,
   deps: [
-    '@gammarer/aws-secure-log-bucket@~0.12',
+    '@gammarer/aws-secure-log-bucket@~1.1.0',
+    '@gammarer/aws-secure-bucket@~1.0.0',
   ],
   peerDeps: [
-    '@gammarer/aws-secure-log-bucket',
-    '@gammarer/aws-secure-bucket',
+    '@gammarer/aws-secure-log-bucket@~1.1.0',
+    '@gammarer/aws-secure-bucket@~1.0.0',
   ],
-  minNodeVersion: '18.0.0',
+  minNodeVersion: '16.0.0',
   workflowNodeVersion: '18.17.1',
   depsUpgradeOptions: {
     workflowOptions: {
@@ -41,5 +44,9 @@ const project = new awscdk.AwsCdkConstructLibrary({
     mavenArtifactId: 'aws-secure-flow-log-bucket',
     mavenEndpoint: 'https://s01.oss.sonatype.org',
   },
+  publishToNuget: {
+    dotNetNamespace: 'Gammarer.CDK.AWS',
+    packageId: 'Gammarer.CDK.AWS.SecureFlowLogBucket',
+  },
 });
 project.synth();
\ No newline at end of file
